@@ -90,7 +90,7 @@ void KDEDAccounts::accountCreated(const Accounts::AccountId id)
     const Accounts::Account *acc = KAccounts::accountsManager()->account(id);
     const Accounts::ServiceList services = acc->enabledServices();
 
-    for (KAccountsDPlugin *plugin : qAsConst(m_plugins)) {
+    for (KAccountsDPlugin *plugin : std::as_const(m_plugins)) {
         plugin->onAccountCreated(id, services);
     }
 }
@@ -99,7 +99,7 @@ void KDEDAccounts::accountRemoved(const Accounts::AccountId id)
 {
     qDebug() << id;
 
-    for (KAccountsDPlugin *plugin : qAsConst(m_plugins)) {
+    for (KAccountsDPlugin *plugin : std::as_const(m_plugins)) {
         plugin->onAccountRemoved(id);
     }
 }
@@ -116,11 +116,11 @@ void KDEDAccounts::enabledChanged(const QString &serviceName, bool enabled)
 
     const Accounts::Service service = KAccounts::accountsManager()->service(serviceName);
     if (!enabled) {
-        for (KAccountsDPlugin *plugin : qAsConst(m_plugins)) {
+        for (KAccountsDPlugin *plugin : std::as_const(m_plugins)) {
             plugin->onServiceDisabled(accId, service);
         }
     } else {
-        for (KAccountsDPlugin *plugin : qAsConst(m_plugins)) {
+        for (KAccountsDPlugin *plugin : std::as_const(m_plugins)) {
             plugin->onServiceEnabled(accId, service);
         }
     }
